@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mock-fs" "0.10.1"
+(define-package "mock-fs" "20260111.410"
   "Virtual filesystem for Emacs Lisp tests."
   '((emacs "27.1"))
   :url "https://codeberg.org/Trevoke/mock-fs.el"
